"""LICENSE
Copyright 2019 Hermann Krumrey <hermann@krumreyh.com>

This file is part of puffotter.

puffotter is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

puffotter is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with puffotter.  If not, see <http://www.gnu.org/licenses/>.
LICENSE"""

import imaplib


def get_inbox_count(
        imap_server: str,
        imap_address: str,
        imap_password: str,
        imap_port: int = 993
) -> int:
    """
    Checks the amount of emails in an IMAP inbox
    :param imap_server: The IMAP server to use
    :param imap_address: The IMAP address to use
    :param imap_password: The IMAP password to use
    :param imap_port: The IMAP port to use
    :return: The amount of emails
    """
    server = imaplib.IMAP4_SSL(imap_server, imap_port)
    server.login(imap_address, imap_password)
    content = server.select("Inbox")[1][0]
    counted = 0 if content is None else int(content)
    server.close()
    server.logout()
    return counted



"""LICENSE
Copyright 2019 Hermann Krumrey <hermann@krumreyh.com>

This file is part of puffotter.

puffotter is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

puffotter is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with puffotter.  If not, see <http://www.gnu.org/licenses/>.
LICENSE"""

import os
from typing import List
from subprocess import check_call, CalledProcessError, STDOUT
from puffotter.print import pprint


def execute_command(command: List[str]) -> int:
    """
    Executes a command
    :param command: The command to execute
    :return: The status code
    """
    pprint(" ".join(command), fg="lyellow")
    with open(os.devnull, "w") as devnull:
        try:
            code = check_call(command, stdout=devnull, stderr=STDOUT)
            if code != 0:
                pprint("Error Code {}".format(code), fg="lred")
            return code
        except CalledProcessError as e:
            pprint("Called Process Error: " + str(e), fg="lred")
            return 1



"""LICENSE
Copyright 2019 Hermann Krumrey <hermann@krumreyh.com>

This file is part of puffotter.

puffotter is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

puffotter is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with puffotter.  If not, see <http://www.gnu.org/licenses/>.
LICENSE"""

from setuptools import setup, find_packages

if __name__ == "__main__":

    setup(
        name="puffotter",
        version=open("version", "r").read(),
        description="Convenience library for python",
        long_description=open("README.md", "r").read(),
        long_description_content_type="text/markdown",
        author="Hermann Krumrey",
        author_email="hermann@krumreyh.com",
        classifiers=[
            "License :: OSI Approved :: GNU General Public License v3 (GPLv3)"
        ],
        url="https://gitlab.namibsun.net/namibsun/python/puffotter",
        license="GNU GPL3",
        packages=find_packages(),
        install_requires=[
            "sentry-sdk",
            "requests",
            "colorama"
        ],
        extras_require={
            "crypto": [
                "bcrypt"
            ]
        },
        test_suite='nose.collector',
        tests_require=['nose'],
        include_package_data=True,
        zip_safe=False
    )



"""LICENSE
Copyright 2019 Hermann Krumrey <hermann@krumreyh.com>

This file is part of puffotter.

puffotter is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

puffotter is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with puffotter.  If not, see <http://www.gnu.org/licenses/>.
LICENSE"""

import requests


def verify_recaptcha(
        client_ip: str,
        recaptcha_response: str,
        secret_key: str
) -> bool:
    """
    Verifies a recaptcha response.
    If the recaptcha response originates from a local address,
    this method will always return True.
    :param client_ip: The IP Address of the client solving the captcha
    :param recaptcha_response: the recaptcha response to verify
    :param secret_key: the recaptcha secret key
    :return: True if the recaptcha response was correct, False otherwise
    """
    return requests.post(
        "https://www.google.com/recaptcha/api/siteverify",
        data={
            "secret": secret_key,
            "response": recaptcha_response,
            "remoteip": client_ip
        }
    ).json().get("success", False)
